pub struct FileReportsDisp<'a, P> { /* private fields */ }Expand description
Pretty-printer for file reports.
Implementations
Sourceimpl<'a, P> FileReportsDisp<'a, P>
impl<'a, P> FileReportsDisp<'a, P>
Sourcepub fn new(file_reports: &'a FileReports<P>) -> Self
pub fn new(file_reports: &'a FileReports<P>) -> Self
Construct a new pretty-printer for file reports.
By default, this does not apply any colors and does not print file paths.
Sourcepub fn with_paint(self, paint: Paint) -> Self
pub fn with_paint(self, paint: Paint) -> Self
Set a function that determines how colors should be applied to text.